==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd.md <==
# AwsDirectoryServiceAwsManagedMicrosoftAd


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')
```



| Illustration | AwsDirectoryServiceAwsManagedMicrosoftAd | AwsDirectoryServiceAwsManagedMicrosoftAdCard | AwsDirectoryServiceAwsManagedMicrosoftAdGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd.png) | ![illustration for AwsDirectoryServiceAwsManagedMicrosoftAd](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd.Local.png) | ![illustration for AwsDirectoryServiceAwsManagedMicrosoftAdCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAdCard.Local.png) | ![illustration for AwsDirectoryServiceAwsManagedMicrosoftAdGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAdGroup.Local.png) |




## AwsDirectoryServiceAwsManagedMicrosoftAd

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAd
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAd('AwsDirectoryServiceAwsManagedMicrosoftAd', 'Aws Directory Service Aws Managed Microsoft Ad', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAd
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAd('AwsDirectoryServiceAwsManagedMicrosoftAd', 'Aws Directory Service Aws Managed Microsoft Ad', 'an optional tech label')
@enduml
```

## AwsDirectoryServiceAwsManagedMicrosoftAdCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAdCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAdCard('AwsDirectoryServiceAwsManagedMicrosoftAdCard', 'Aws Directory Service Aws Managed Microsoft Ad Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAdCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAdCard('AwsDirectoryServiceAwsManagedMicrosoftAdCard', 'Aws Directory Service Aws Managed Microsoft Ad Card', 'an optional description')
@enduml
```

## AwsDirectoryServiceAwsManagedMicrosoftAdGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAdGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAdGroup('AwsDirectoryServiceAwsManagedMicrosoftAdGroup', 'Aws Directory Service Aws Managed Microsoft Ad Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAdGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAdGroup('AwsDirectoryServiceAwsManagedMicrosoftAdGroup', 'Aws Directory Service Aws Managed Microsoft Ad Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd.md <==
# AwsDirectoryServiceAwsManagedMicrosoftAd


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')
```



| Illustration | AwsDirectoryServiceAwsManagedMicrosoftAd | AwsDirectoryServiceAwsManagedMicrosoftAdCard | AwsDirectoryServiceAwsManagedMicrosoftAdGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd.png) | ![illustration for AwsDirectoryServiceAwsManagedMicrosoftAd](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd.Local.png) | ![illustration for AwsDirectoryServiceAwsManagedMicrosoftAdCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAdCard.Local.png) | ![illustration for AwsDirectoryServiceAwsManagedMicrosoftAdGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAdGroup.Local.png) |




## AwsDirectoryServiceAwsManagedMicrosoftAd

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAd
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAd('AwsDirectoryServiceAwsManagedMicrosoftAd', 'Aws Directory Service Aws Managed Microsoft Ad', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAd
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAd('AwsDirectoryServiceAwsManagedMicrosoftAd', 'Aws Directory Service Aws Managed Microsoft Ad', 'an optional tech label')
@enduml
```

## AwsDirectoryServiceAwsManagedMicrosoftAdCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAdCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAdCard('AwsDirectoryServiceAwsManagedMicrosoftAdCard', 'Aws Directory Service Aws Managed Microsoft Ad Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAdCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAdCard('AwsDirectoryServiceAwsManagedMicrosoftAdCard', 'Aws Directory Service Aws Managed Microsoft Ad Card', 'an optional description')
@enduml
```

## AwsDirectoryServiceAwsManagedMicrosoftAdGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAdGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAdGroup('AwsDirectoryServiceAwsManagedMicrosoftAdGroup', 'Aws Directory Service Aws Managed Microsoft Ad Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsDirectoryServiceAwsManagedMicrosoftAdGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsDirectoryServiceAwsManagedMicrosoftAd')

' renders the element
AwsDirectoryServiceAwsManagedMicrosoftAdGroup('AwsDirectoryServiceAwsManagedMicrosoftAdGroup', 'Aws Directory Service Aws Managed Microsoft Ad Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
